package com.srs.system.mapper;

import java.util.List;

import com.srs.system.domain.SysDeptMap;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 部门映射Mapper接口
 *
 * @author srs
 * @date 2024-05-13
 */
public interface SysDeptMapMapper extends BaseMapper<SysDeptMap> {
    /**
     * 查询部门映射
     *
     * @param id 部门映射主键
     * @return 部门映射
     */
    public SysDeptMap selectSysDeptMapById(Long id);

    /**
     * 查询部门映射列表
     *
     * @param sysDeptMap 部门映射
     * @return 部门映射集合
     */
    List<SysDeptMap> selectSysDeptMapList(SysDeptMap sysDeptMap);

    /**
     * 新增部门映射
     *
     * @param sysDeptMap 部门映射
     * @return 结果
     */
    int insertSysDeptMap(SysDeptMap sysDeptMap);

    /**
     * 修改部门映射
     *
     * @param sysDeptMap 部门映射
     * @return 结果
     */
    int updateSysDeptMap(SysDeptMap sysDeptMap);

    /**
     * 删除部门映射
     *
     * @param id 部门映射主键
     * @return 结果
     */
    int deleteSysDeptMapById(Long id);

    /**
     * 批量删除部门映射
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysDeptMapByIds(Long[] ids);
}
